@@ -419,6 +419,7 @@ class FlatpakTransaction():
         self.transaction.connect("operation-done", self._operation_done)
         self.transaction.connect("operation-error", self._operation_error)
         self.transaction.connect("add-new-remote", self._transaction_add_new_remote)
+        self.transaction.connect("end-of-lifed", self._ref_eoled)
         self.transaction.connect("end-of-lifed-with-rebase", self._ref_eoled_with_rebase)
 
         # Runtimes explicitly installed are 'pinned' - which means they'll never be automatically
@@ -678,18 +679,24 @@ class FlatpakTransaction():
         debug("Adding new remote '%s' (%s) for %s: %s" % (suggested_remote_name, url, from_id, reason))
         return True
 
+    def _ref_eoled(self, transaction, ref, reason, rebase):
+        warn("%s is end-of-life (EOL) (%s)" % (ref, reason))
+
     def _ref_eoled_with_rebase(self, transaction, remote, ref, reason, rebased_to_ref, prev_ids):
-        warn("%s is EOL (%s). Replacing with %s" % (ref, reason, rebased_to_ref))
+        warn("%s is end-of-life (EOL) (%s)" % (ref, reason))
 
         try:
             transaction.add_uninstall(ref)
         except:
             pass
-        try:
-            transaction.add_rebase(rebased_to_ref)
-        except:
-            debug("No new ref to rebase to, using the eol'd one")
-            return False
+
+        if rebased_to_ref is not None:
+            try:
+                warn("Replacing with %s" % rebased_to_ref)
+                transaction.add_rebase(remote, rebased_to_ref, None, prev_ids)
+            except GLib.Error as e:
+                debug("Problem adding replacement ref: %s" % e.message)
+                return False
 
         return True
 
