@@ -153,7 +153,7 @@ class InstallerTask:
         return self.transaction_log
 
     def call_info_ready_callback(self):
-        if self.info_ready_callback == None:
+        if self.info_ready_callback is None:
             return
 
         if self.use_mainloop:
@@ -168,7 +168,7 @@ class InstallerTask:
             self.error_message = str(error)
 
         if info_stage:
-            if self.info_error_callback == None:
+            if self.info_error_callback is None:
                 dialogs.show_error(self.error_message, self.parent_window)
                 return
 
@@ -197,8 +197,13 @@ class InstallerTask:
         else:
             self.error_cleanup_cb(self)
 
-class Installer:
+class Installer(GObject.Object):
+    __gsignals__ = {
+        'appstream-changed': (GObject.SignalFlags.RUN_LAST, None, ()),
+    }
     def __init__(self, pkg_type=PKG_TYPE_ALL, temp=False):
+        GObject.Object.__init__(self)
+
         self.tasks = {}
         self.pkg_type = pkg_type
 
@@ -253,7 +258,7 @@ class Installer:
         if self.cache.status == self.cache.STATUS_OK and not self.remotes_changed:
             self.inited = True
 
-            GObject.idle_add(self.initialize_appstream)
+            self.initialize_appstream()
             self.generate_uncached_pkginfos(self.cache)
 
             return True
@@ -302,7 +307,7 @@ class Installer:
             self._store_remotes()
             self.remotes_changed = False
 
-        GObject.idle_add(self.initialize_appstream)
+        self.initialize_appstream()
 
         self.generate_uncached_pkginfos(self.cache)
 
@@ -531,9 +536,12 @@ class Installer:
         display info for packages.
         """
         if self.have_flatpak:
-            _flatpak.initialize_appstream()
+            _flatpak.initialize_appstream(self.on_appstream_loaded)
         # Is there any reason to use apt's appstream?
 
+    def on_appstream_loaded(self):
+        self.emit("appstream-changed")
+
     def get_appstream_app_for_pkginfo(self, pkginfo):
         try:
             backend_component = self.backend_table[pkginfo]
@@ -735,7 +743,7 @@ class Installer:
         see the task's progress (and cancel it if desired.)
         """
 
-        if task.pkginfo != None:
+        if task.pkginfo is not None:
             key = task.pkginfo.pkg_hash
         else:
             key = "updates"
